#!/bin/bash -e
# Script & lists for building Xorg
# Originally based on lists from BLFS for Xorg 7.2
# By Curaga

# Run from the directory where you keep your X tarballs
# Run as root, have Mesa* extracted into
export MESA_PATH="/tmp/Mesa-7.10.3"

export XORG_CONFIG="--prefix=/usr/local --sysconfdir=/etc \
    --mandir=/usr/local/share/man --localstatedir=/var"
export BASE_CONFIG="--prefix=/usr --sysconfdir=/etc --bindir=/usr/local/bin \
    --mandir=/usr/local/share/man --localstatedir=/var --disable-static"

export DRIVER_CONFIG="--with-xorg-module-dir=/usr/local/lib/X11/modules"

export CFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export CXXFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export LDFLAGS="-Wl,-O1"
export PKG_CONFIG_PATH="/usr/local/lib/pkgconfig"

for i in *proto*xz; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 ./configure $XORG_CONFIG
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done

for i in makedepend-* util-macros-*; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 ./configure $XORG_CONFIG
 make -j5
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done

for i in `cat lib.list`; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 case $i in
	libX11*)
 ./configure $BASE_CONFIG --without-xcb
	;;
	libXau*|libXdmc*|libXext*|libXfont*|libXft*|libXi-*|libXmu*|libXmuu*|libXpm*|libXrand*|libXrend*|libXt-*|libSM*|libICE*)
 ./configure $BASE_CONFIG
	;;
	*)
 ./configure $XORG_CONFIG
	;;
 esac
 make -j5
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done

cd $MESA_PATH
 ./configure --with-dri-driverdir=/usr/local/lib/X11/modules/dri \
 --enable-glx-tls --disable-gallium \
 --with-xorg-driver-dir=/usr/local/lib/X11/modules
 make -j5
 make DESTDIR=/tmp/dest install
cd -

for i in mesa-demos*; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir/src/xdemos
 for j in glxgears glxinfo; do
	gcc -o $i ${i}.c -lGL $CFLAGS $LDFLAGS
	cp $i /tmp/dest/usr/local/bin
 done
 cd ../../..; cp -a /tmp/dest/* /
 rm -rf $dir
done

for i in `cat app.list`; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 ./configure $XORG_CONFIG
 make -j5
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done

for i in xkeyboard-config-*; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 ./configure $XORG_CONFIG --with-xkb-rules-symlink=xorg
 make -j5
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done

for i in luit-*; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 ./configure $XORG_CONFIG --with-localealiasfile=/usr/local/share/X11/locale/locale.alias
 make -j5
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done

export SHA1_LIBS="-ldl /usr/local/lib/libcrypto.a -ldl"
export SHA1_CFLAGS="-I/usr/local/include"

for i in xorg-server-*; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 ./configure $XORG_CONFIG --enable-kdrive  --enable-install-setuid \
 --with-vendor-name="TinyCore Linux" --with-vendor-name-short="TinyCore" \
 --with-vendor-web="www.tinycorelinux.com"  \
 --with-module-dir=/usr/local/lib/X11/modules  --with-xkb-output=/var/lib/xkb \
 --enable-glx-tls --with-fontrootdir=/usr/lib/X11/fonts

 rm /usr/local/lib/libcrypto.so # Force the sucker to link statically.

 make -j5
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done

unset SHA1_LIBS SHA1_CFLAGS

for i in `cat driver.list`; do
 ls $i
 dir=$(echo $i | sed 's/.tar.xz//')
 tar -xf $i
 cd $dir
 ./configure $XORG_CONFIG $DRIVER_CONFIG
 make -j5
 make DESTDIR=/tmp/dest install
 cd ..; cp -a /tmp/dest/* /
 rm -rf $dir
done
